# Mikidown

Mikidown is note taking application with markdown support.

> Mikidown was inspired by [Zim] and based on [ReText].

## Features 

- Take and organize notes in markdown
- Page cross-link
- Live preview
- Import and save as plain text files
- Export to HTML, PDF
- Support multiple notebooks 
- Customise your note style (by editing CSS file)

## Dependencies

- Python (>3.0)
- PyQt
- python-markdown
- python-whoosh

## How-To

    git clone git@github.com:rnons/mikidown.git
    cd mikidown

You should be able to **run** mikidown with <code>./mikidown.py</code>. 

To install
 
    python setup.py install
    mikidown

## Use Mikidown to visualize you notes

In case you are unfamiliar with markdown, you can use this file (**Help->README**) as a simple reference to basic markdown syntax. However, I suggest you take a look at the complete [Markdown Syntax].

### [Footnote Syntax]

    Footnotes[^1] have a label and a definition.

    [^1]: This is a footnote

### Mikidown Specific Syntax

1.  page cross link, all of the three will do 

    `[text](/parentNode/childNode/pageName)`

*Feature to come*:

    `[text](/parentNode/childNode/pageName#anchor)`


2.  mikidown support both absolute and relative image path 

    `![text](file:///home/user/pic.png)` 
    `![text](pic.png)`     # path relative to notebook folder

`Ctrl + I` or **Edit -> Insert Image** will bring up an *insert image* dialog.

3.  ins/del/bold/italics (better view in mikidown)

- `~~delete~~`  will yield ~~delete~~
- `__insert__` will yield __insert__
- `**strong**` will yield **strong**
- `//emphasis//` will yield //emphasis//

## Contributor

[ShadowKyogre]

[Fork and help] are much appreciated.

[Zim]: http://zim-wiki.org/
[ReText]: http://sourceforge.net/p/retext/
[Markdown Syntax]: http://daringfireball.net/projects/markdown/syntax
[Fork and help]: https://github.com/rnons/mikidown
[ShadowKyogre]: https://github.com/ShadowKyogre
[Footnote Syntax]: http://pythonhosted.org/Markdown/extensions/footnotes.html
